% Matlab Dewesoft import - version 1.0
%
% supports basic parameters transfer (sample rate,...)
% supports direct buffer data (synch and asynch)
% channel names, colors, timestamps

% clear old variables
clear;

h = actxserver('Dewesoft.App');
h.Init();
h.Visible = true;
h.Width = 800;
h.Height = 600;

h.SetupScreen;

h.Data.AllChannels.Item(0).Used = true;
h.Data.AllChannels.Item(1).Used = true;

h.StartStoring('c:\test_d1.d7d');
pause(5);
h.Stop();

h.LoadFile('c:\test_d1.d7d');

data_sections = h.LoadEngine.DataSections;
disp(sprintf('Number of data sections %d', data_sections.Count));
data_section = data_sections.Item(0);

sample_rate = h.Data.SampleRate;
disp(sprintf('Sample rate: %d', sample_rate));
%disp(sprintf('Start store time: %d', h.));
%disp(sprintf('File duration: %d', info_data.duration));

% read number of channels in Dewesoft
channel_count = h.Data.UsedChannels.Count;
disp(sprintf('Number of channels: %d', channel_count));

% y axis has channel names label
ylabel_str = '';
% maximum time for data
max_out_time = 0;

% go through all the channels and find color, name... and index
for i = 0:channel_count - 1 
    ch = h.Data.UsedChannels.Item(i);
    out_name = ch.Name;
    out_color = ch.MainDisplayColor();
    
    % build y string for channel names
    ylabel_str = strcat(ylabel_str, ', ', out_name);
       
    % get number of samples for channel
    sample_cnt = data_section.DataCount;
    
    % draw graph only once
    if i == 0  
        figure;
    end;
    
    % if there is some samples in the data file then read sample values and
    % corresponding time stamps (also synchronous channels have timestamps)
    if sample_cnt > 0 
        [out_data, out_time_stamp] = data_section.ReadData(ch);
        if isnan(out_time_stamp)
            out_time_stamp = [0:1/sample_rate:(sample_cnt - 1)/sample_rate];
        end;
        
        % maximum for x axis
        max_out_time = max(max_out_time, out_time_stamp(length(out_time_stamp))); 

        % plot data on one graph color read out from file
        colr = [bitand(uint32(out_color), 16711680) / 16711680, bitand(uint32(out_color), 65280) / 65280, bitand(uint32(out_color), 255) / 255];
        plot(out_time_stamp, out_data, 'Color', colr)
        
        hold on;
    end;
end;

title(sprintf('Number of channels: %d', channel_count));
% set channel names on y label
ylabel(strcat('Dewesoft channels: ', ylabel_str));
% set corret min and max on x and y axis
axis([0, max_out_time, -5, 5]); 

h = 0;